@@ -3,8 +3,8 @@ use crate::openapi::v3::gen::{
     OperationInput, OperationOutput, Options,
 };
 use actix_web::{
-    web::{Data, Form, Header, HttpRequest, Json, Path, Payload, Query},
-    HttpResponse, HttpResponseBuilder,
+    web::{Data, Form, Header, Json, Path, Payload, Query},
+    HttpResponse, HttpResponseBuilder, HttpRequest,
 };
 use schemars::JsonSchema;
 
